ecos_python: Embedded Cone Solver (Python wrapper)
==================================================

Description
-----------

This is the Python package for ECOS: Embedded Cone Solver.

It vendors ECOS.

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/ecos/

